/*
 * Copyright (c) 2009 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package org.ow2.petals.kernel.ws.api;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;

import org.ow2.petals.kernel.ws.api.to.AttachmentDescriptor;

/**
 * Access to the artifact repository service
 *
 * @author Christophe HAMERLING - eBM WebSourcing
 *
 */
@WebService(name = "ArtifactRepositoryService")
public interface ArtifactRepositoryService {

    /**
     * Upload the artifact to the PEtALS container. This will add the artifact
     * to the repository service depending on its type (component, service
     * assembly, shared library)
     *
     * @param attachmentDescriptor
     * @return
     */
    @WebMethod
    boolean addArtifact(@WebParam(name = "attachment") AttachmentDescriptor attachmentDescriptor)
            throws PEtALSWebServiceException;

    /**
     * Get all the components which are available in the repository
     *
     * @return
     */
    @WebMethod
    @WebResult(name = "component")
    String[] getComponents();

    /**
     * Get all the service assemblies which are available in the repository
     *
     * @return
     */
    @WebMethod
    @WebResult(name = "sa")
    String[] getServiceAssemblies();

    /**
     * Get all the shared libraries which are available in the repository
     *
     * @return
     */
    @WebMethod
    @WebResult(name = "sl")
    String[] getSharedLibraries();

}
